MicAudioStatus class

Inheritance

Constructors

MicAudioStatus({required bool isActive, String? deviceName})
const
MicAudioStatus.fromJson(Map<String, dynamic> json)
factory

Properties

deviceName → String?
final
hashCode → int
The hash code for this object.
no setteroverride
isActive → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isActive, String? deviceName}) → MicAudioStatus
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override